@@ -11,7 +11,7 @@
  */
 /*
  *  This file is part of AutoGen.
- *  AutoGen Copyright (C) 1992-2015 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (C) 1992-2016 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -274,7 +274,7 @@ insert_ent(def_ent_t * de)
                sizeof(def) - ag_offsetof(def_ent_t, de_name));
 
         /*
-         * Contents are swapped.  Link "de" after "de_list" and return "de_list".
+         * Contents are swapped.  Link "de" after "de_list" & return "de_list".
          */
         de->de_twin = de_list->de_twin;
         if (de->de_twin != NULL)
@@ -386,14 +386,14 @@ ready_def_input(char const ** ppzfile, size_t * psz)
     if (strcmp(*ppzfile, "-") == 0) {
         *ppzfile = OPT_ARG(DEFINITIONS) = "stdin";
         if (getenv(REQUEST_METHOD) != NULL) {
-            loadCgi();
+            load_cgi();
             cctx = base_ctx;
             dp_run_fsm();
             return INPUT_DONE;
         }
 
     accept_fifo:
-        outfile_time  = time(NULL);
+        maxfile_time = outfile_time = time(NULL);
         *psz = 0x4000 - (4+sizeof(*base_ctx));
         return INPUT_STDIN;
     }
@@ -421,6 +421,7 @@ ready_def_input(char const ** ppzfile, size_t * psz)
      */
     *psz = (size_t)stbf.st_size;
 
+    maxfile_time = stbf.st_mtime;
     outfile_time = ENABLED_OPT(SOURCE_TIME) ? stbf.st_mtime : time(NULL);
 
     return INPUT_FILE;
