@@ -2,7 +2,7 @@
 
 ##  This file is part of AutoOpts, a companion to AutoGen.
 ##  AutoOpts is free software.
-##  AutoOpts is Copyright (C) 1992-2014 by Bruce Korb - all rights reserved
+##  AutoOpts is Copyright (C) 1992-2016 by Bruce Korb - all rights reserved
 ##
 ##  AutoOpts is available under any one of two licenses.  The license
 ##  in use must be one of these two and the choice is under the control
@@ -31,7 +31,6 @@ die() {
 
 init() {
     PS4='>tpc-${FUNCNAME}> '
-    set -e
     progpid=$$
     prog=`basename $0`
     progdir=`\cd \`dirname $0\` >/dev/null ; pwd`
@@ -56,6 +55,8 @@ collect_src() {
 	#include "autoopts/project.h"
 	#define  LOCAL static
 	#include "ao-strs.h"
+	static char const ao_ver_string[] =
+	    "${AO_CURRENT}:${AO_REVISION}:${AO_AGE}\n";
 	_EOF_
 
     for f in "$@"
@@ -90,19 +91,7 @@ extension_defines() {
     mv -f  tpl-config.$$  tpl-config.tlib
 }
 
-set_shell_prog() {
-    case `uname -s` in
-    SunOS )
-      while : ; do
-        POSIX_SHELL=`which bash`
-        test -x "${POSIX_SHELL}" && break
-        POSIX_SHELL=/usr/xpg4/bin/sh
-        test -x "${POSIX_SHELL}" && break
-        die "You are hosed.  You are on Solaris and have no usable shell."
-      done
-      ;;
-    esac
-
+fix_scripts() {
     for f in ${srcdir}/tpl/*.sh ${srcdir}/tpl/*.pl
     do
         d=`basename $f | sed 's/\.[sp][hl]$//'`
@@ -122,9 +111,30 @@ set_shell_prog() {
         esac > $d
         chmod 755 $d
     done
+
+    for f in ${srcdir}/tpl/*.pm
+    do
+        test -f ${f##*/} && continue
+        cp $f ${f##*/}
+        chmod 644 ${f##*/}
+    done
 }
 
-set_cat_prog() {
+find_shell_prog() {
+    case `uname -s` in
+    SunOS )
+      while : ; do
+        POSIX_SHELL=`which bash`
+        test -x "${POSIX_SHELL}" && break
+        POSIX_SHELL=/usr/xpg4/bin/sh
+        test -x "${POSIX_SHELL}" && break
+        die "You are hosed.  You are on Solaris and have no usable shell."
+      done
+      ;;
+    esac
+}
+
+find_cat_prog() {
     while :
     do
         \unalias -a
@@ -158,14 +168,14 @@ scan_cflags() {
     do
         case "$1" in
         -I )
-            test -f $2/libguile/__scm.h && {
+            test -f "$2/libguile/__scm.h" && {
                 libguiledir=$2
                 return 0
             }
             ;;
         -I* )
             f=${1#-I}
-            test -f $f/libguile/__scm.h && {
+            test -f "$f/libguile/__scm.h" && {
                 libguiledir=$f
                 return 0
             }
@@ -185,22 +195,30 @@ find_libguiledir() {
 
     if test -d "${libguiledir}"
     then
-        test -d ${libguiledir}/guile && libguiledir=${libguiledir}/guile
+        test -f ${libguiledir}/libguile.h || {
+            set -- ${libguiledir}/*guile*/.
+            if test -d "${2}"
+            then libguiledir=${2%/.}
+            elif test -d "$1"
+            then libguiledir=${1%/.}
+            fi
+        }
+
         v=`guile-config --version 2>&1 | sed 's/.* version //'`
         test -d ${libguiledir}/${v%.*} && v=${v%.*}
         test -d ${libguiledir}/${v} && libguiledir=${libguiledir}/$v
 
     else
-        scan_cflags "$@"
+        scan_cflags $*
     fi
     guile_scm_h=`find ${libguiledir} -type f -name __scm.h`
 }
 
 fix_guile() {
     cd ${builddir}
-    find_libguiledir "${LGCFLAGS}"
+    find_libguiledir ${LGCFLAGS}
 
-    list=`set +e ; exec 2>/dev/null
+    list=`exec 2>/dev/null
         find ${libguiledir}/libguile* -type f | \
             xargs grep -l -E '\<noreturn\>'`
 
@@ -228,7 +246,8 @@ fix_guile() {
 init
 collect_src "$@" > ${builddir}/libopts.c
 extension_defines
-set_shell_prog
-set_cat_prog
+fix_scripts
+find_shell_prog
+find_cat_prog
 fix_guile
 touch ${sentinel_file}
